@@ -113,7 +113,7 @@ setMethod(
     definition = function(object, object2, ...)
     {
         class(object) <- 'SingleGroupClass'
-        anova(object, object2, ...)
+        anova(object, object2, ..., frame = 2)
     }
 )
 
