@@ -202,13 +202,13 @@ EM.group <- function(pars, constrain, Ls, Data, PrepList, list, Theta, DERIV, so
         for(g in seq_len(ngroups)){
             if(dentype == 'bfactor'){
                 rlist[[g]] <- Estep.bfactor(pars=pars[[g]], tabdata=Data$tabdatalong, freq=Data$Freq[[g]],
-                                            Theta=Theta, prior=prior[[g]],
+                                            Theta=Theta, prior=prior[[g]], wmiss=Data$wmiss,
                                             Priorbetween=Priorbetween[[g]], specific=specific,
                                             sitems=sitems, itemloc=itemloc, CUSTOM.IND=CUSTOM.IND,
                                             omp_threads=list$omp_threads)
             } else {
                 rlist[[g]] <- Estep.mirt(pars=pars[[g]], tabdata=Data$tabdatalong, freq=Data$Freq[[g]],
-                                         CUSTOM.IND=CUSTOM.IND, Theta=Theta,
+                                         CUSTOM.IND=CUSTOM.IND, Theta=Theta, wmiss=Data$wmiss,
                                          prior=Prior[[g]], itemloc=itemloc, omp_threads=list$omp_threads)
             }
             LL <- LL + sum(Data$Freq[[g]]*log(rlist[[g]]$expected))
@@ -282,7 +282,7 @@ EM.group <- function(pars, constrain, Ls, Data, PrepList, list, Theta, DERIV, so
                     pars[[g]][[J+1L]]@rrb <- rlist[[g]]$r2
                     pars[[g]][[J+1L]]@rrs <- rlist[[g]]$r3
                 } else {
-                    pars[[g]][[J+1L]]@rr <- rowSums(rlist[[g]]$r1) / J
+                    pars[[g]][[J+1L]]@rr <- rlist[[g]]$r1g
                     if(dentype == 'EHW' && g == 1L || dentype == "Davidian" ||
                        (dentype == 'custom' && pars[[g]][[J+1L]]@standardize))
                         pars[[g]][[J+1L]]@rr <- standardizeQuadrature(gTheta[[g]],
@@ -410,8 +410,8 @@ EM.group <- function(pars, constrain, Ls, Data, PrepList, list, Theta, DERIV, so
             rlist <- Elist$rlist; LL <- Elist$LL
         }
         if(cycles == NCYCLES){
-            if(list$message)
-                message('EM cycles terminated after ', cycles, ' iterations.')
+            if(list$warn)
+                warning('EM cycles terminated after ', cycles, ' iterations.')
             converge <- FALSE
         } else if(cycles == 1L && !all(!est)){
             if(list$warn && !(is.nan(TOL) || is.na(TOL)) && !list$NULL.MODEL)
@@ -479,19 +479,17 @@ EM.group <- function(pars, constrain, Ls, Data, PrepList, list, Theta, DERIV, so
             }
         }
         if(dentype == 'mixture'){
-            mixtype <- new('lca', par=sapply(1L:length(pars),
-                    function(g) sum(pars[[g]][[J+1L]]@par[length(pars[[g]][[J+1L]]@par)])),
-                    est=as.logical(sapply(1L:length(pars),
-                                          function(g) sum(pars[[g]][[J+1L]]@est[length(pars[[g]][[J+1L]]@est)]))),
-                    parnum=sapply(1L:length(pars),
-                                  function(g) sum(pars[[g]][[J+1L]]@parnum[length(pars[[g]][[J+1L]]@parnum)])),
-                    nfact=length(pars), ncat=length(pars),
-                    any.prior=FALSE, itemclass=10L,
-                    dat=matrix(sapply(1L:length(pars),
-                                      function(g) sum(pars[[g]][[J+1L]]@rr)), 1L))
-            mixtype@item.Q <- matrix(1, nrow = mixtype@ncat, ncol = mixtype@nfact)
-            deriv <- Deriv(mixtype, Theta = matrix(1, 1L, length(pars)), estHess=TRUE)
-            h[mixtype@parnum, mixtype@parnum] <- deriv$hess
+            mixtype <- list(par=sapply(1L:length(pars),
+                                       function(g) sum(pars[[g]][[J+1L]]@par[length(pars[[g]][[J+1L]]@par)])),
+                            est=as.logical(sapply(1L:length(pars),
+                                                  function(g) sum(pars[[g]][[J+1L]]@est[length(pars[[g]][[J+1L]]@est)]))),
+                            parnum=sapply(1L:length(pars),
+                                          function(g) sum(pars[[g]][[J+1L]]@parnum[length(pars[[g]][[J+1L]]@parnum)])),
+                            any.prior=FALSE,
+                            dat=matrix(sapply(1L:length(pars),
+                                              function(g) sum(pars[[g]][[J+1L]]@rr)), 1L))
+            deriv <- Deriv.mix(mixtype, estHess=TRUE)
+            h[mixtype$parnum, mixtype$parnum] <- deriv$hess
         } else mixtype <- NULL
         hess <- updateHess(h=h, L=L)
         hess <- as.matrix(hess[estpars & !redun_constr, estpars & !redun_constr])
