@@ -57,7 +57,7 @@ setMethod(
     definition = function(object, object2, ...)
     {
         class(object) <- 'SingleGroupClass'
-        anova(object, object2, ...)
+        anova(object, object2, ..., frame = 2)
     }
 )
 
@@ -80,6 +80,9 @@ setMethod(
             stop(type, " is not a valid plot type.", call.=FALSE)
         if (any(degrees > 90 | degrees < 0))
             stop('Improper angle specified. Must be between 0 and 90.', call.=FALSE)
+        dots <- list(...)
+        if(!is.null(dots$MI))
+            warning('MI option not currently supported for multiple-group objects', call.=FALSE)
         rot <- list(x = rot[[1]], y = rot[[2]], z = rot[[3]])
         ngroups <- x@Data$ngroups
         J <- x@Data$nitems
